@@ -1,8 +1,8 @@
 use anyhow::Error;
 use chrono::{DateTime, FixedOffset, NaiveDate, Utc};
 use serde::{Deserialize, Serialize};
-use stack_string::StackString;
-use std::{collections::BTreeMap, io::Write};
+use stack_string::{format_sstr, StackString};
+use std::{collections::BTreeMap, fmt::Write as FmtWrite, io::Write};
 
 use crate::{
     humidity::Humidity,
@@ -145,28 +145,20 @@ impl WeatherForecast {
     /// # Ok(())
     /// # }
     /// ```
-    pub fn get_forecast(&self) -> Result<Vec<String>, Error> {
+    pub fn get_forecast(&self) -> Result<Vec<StackString>, Error> {
         let mut output = vec!["\nForecast:\n".into()];
         output.extend(self.get_high_low().into_iter().map(|(d, (h, l, r, s))| {
-            format!(
-                "\t{} {:25} {:25} {:25}\n",
-                d,
-                format!("High: {:0.1} F / {:0.1} C", h.fahrenheit(), h.celcius(),),
-                format!("Low: {:0.1} F / {:0.1} C", l.fahrenheit(), l.celcius(),),
-                format!(
-                    "{}{}",
-                    if r.millimeters() > 0.0 {
-                        format!("Rain {:0.2} in", r.inches())
-                    } else {
-                        "".to_string()
-                    },
-                    if s.millimeters() > 0.0 {
-                        format!("Snow {:0.2} in", s.inches())
-                    } else {
-                        "".to_string()
-                    },
-                )
-            )
+            let high = format_sstr!("High: {:0.1} F / {:0.1} C", h.fahrenheit(), h.celcius());
+            let low = format_sstr!("Low: {:0.1} F / {:0.1} C", l.fahrenheit(), l.celcius());
+            let mut rain_snow = StackString::new();
+            if r.millimeters() > 0.0 {
+                rain_snow.push_str(&format_sstr!("Rain {:0.2} in", r.inches()));
+            }
+            if s.millimeters() > 0.0 {
+                if !rain_snow.is_empty() {rain_snow.push_str("\t");}
+                rain_snow.push_str(&format_sstr!("Snow {:0.2} in", s.inches()));
+            }
+            format_sstr!("\t{d} {high:25} {low:25} {rain_snow:25}\n")
         }));
         Ok(output)
     }
